@@ -4,6 +4,7 @@
 ******************************************************************************
 """
 
+import os
 import sys
 import signal
 from .utils import Utils
@@ -18,16 +19,20 @@ class Init:
         signal.signal(signal.SIGINT, self.signal_handler)
         signal.signal(signal.SIGTERM, self.signal_handler)
         self.utils = Utils(self)
-        self.package = Package(self)
         self.machine = Machine(self)
         self.armcnc = CNC(self)
+        self.package = Package(self)
         self.start()
 
     def start(self):
         armcnc_start = "armcnc_start"
         if armcnc_start in dir(launch_file):
-            self.armcnc.start()
-            self.package.handwheel.init_serial()
+            var_name = "MACHINE_PATH"
+            if var_name in os.environ:
+                env_var = os.environ[var_name]
+                if env_var != "":
+                    self.machine.machine_path = env_var
+                    self.armcnc.start()
             getattr(launch_file, armcnc_start)(self)
         self.signal_handler(False, False)
 
